<?php

namespace Drupal\json_users_import\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Serialization\Json;
use Drupal\json_users_import\Controller\JsonUsersImportController;

/**
 * Provides a form to import the users from Json
 */
class JsonUsersImport extends FormBase {
	
	/**
	 * Implements \Drupal\Core\Form\FormInterface::getFormID().
	 */
	public function getFormId() {
		return 'json_users_import_form';
	}

	/**
   * {@inheritdoc}
   */
	public function buildForm(array $form, FormStateInterface $form_state) {
		
		$form['user_import_config'] = [
			'#type' => 'details',
			'#title' => t('User Import Configuration'),
			'#attributes' => ['id' => ['user_import_config']],
			'#open' => TRUE,
		];
		$form['user_import_config']['jsonDataKey'] = [
			'#type' => 'textarea',
			'#title' => t("Map the data with appropriate key (name & email keys are mandatory)"),
			'#description' => '<p>' . t('Enter one value per line, in the format fieldname|datakey.') .'<span> Use email as the fieldname for email and name as the fieldname for username in the json.</span></p><p>'. t('The fieldname is the machine name of the fields in the ').'<a href="admin/config/people/accounts/fields">'. t('user account settings') .'.</a>'.t( ' The jsondatakey is the key in the json data.'). '<span> Ex: [{"useremail": "test@test.com","username": "testuser"}].</span></p><p>From above ex, useremail is the jsondatakey. So we need to configure like email|useremail & name|username one by one.</p><p> We can add custom fields and map the key as per your need.</p>',
			'#required' => TRUE,
		];
		$form['user_import'] = [
	      '#title' => $this->t('Paste your json here'),
	      '#type' => 'textarea',
	      '#rows' => 24,
	      '#required' => TRUE,
	    ];
	    $form['actions'] = ['#type' => 'actions'];
	    $form['actions']['submit'] = [
	      '#type' => 'submit',
	      '#value' => $this->t('Import'),
	      '#button_type' => 'primary',
	    ];
		return $form;
	}

	/**
   * {@inheritdoc}
   */
	public function validateForm(array &$form, FormStateInterface $form_state) {

	}

	/**
   * {@inheritdoc}
   */
	public function submitForm(array &$form, FormStateInterface $form_state) {
		$jsonDataKey = $form_state->getValue('jsonDataKey');
		$splitKey = explode(PHP_EOL, $jsonDataKey);
		foreach ($splitKey as $value) {
			$splitKeyarray = explode('|', $value);
			$jsonKey[$splitKeyarray[0]] = $splitKeyarray[1];
		}
		$users_json = $form_state->getValue('user_import');
		$json_decoded = Json::decode($users_json);
		if(is_array($json_decoded)) {
			$operations = [['creating_users_batch', [$json_decoded, $jsonKey]]];
      $batch = [
        'title' => $this->t('Creating Users ...'),
        'operations' => $operations,
        'finished' => 'users_finished_batch',
      ];
      batch_set($batch);
		} else {
			\Drupal::messenger()->addMessage("Not a valid Json!");
		}
	}
}